import fundamentos.*;

/**
 * Esta clase contiene una ventana donde se dibuja la órbita de dos astros
 * 
 * @author (Michael) 
 * @version (20 feb 2015)
 */
public class Espacio
{
    // astros
    public static final int PLUTON=1;
    public static final int CARONTE=2;

    // ventana para hacer el dibujo
    private Dibujo dib;

    // limites de las coordenadas X e Y, en pixeles
    private int limiteX=400;
    private int limiteY=400;

    // factor de escala entre los metros y los pixeles
    private double escala=100000; // metros por pixel

    /**
     * Constructor que crea la ventana y pinta la tierra
     */
    public Espacio() {
        dib=new Dibujo("Simulacion de astros", limiteX*2,limiteY*2);
        dib.ponGrosorLapiz(3);
        dib.pinta();
    }

    /**
     * Pinta el astro que se indica (PLUTON o CARONTE) en la ventana,
     * con las coordenadas indicadas por x e y, en metros
     */
    public void pintaAstro(double x, double y, int numAstro){
        if (numAstro==PLUTON) {
            dib.ponColorLapiz(ColorFig.rojo);
        } else {
            dib.ponColorLapiz(ColorFig.azul);
        }
        dib.dibujaPunto((int)(x/escala)+limiteX, limiteY-(int)(y/escala));
        dib.pinta();
    }

    /**
     * Borra las trayectorias de los astros y pinta la leyenda en el dibujo
     */
    public void borra() {
        dib.borra();
        dib.ponColorLapiz(ColorFig.rojo);
        dib.dibujaLinea(0,40, 30,40);
        dib.dibujaImagen(48,8,"pluton.png");
        dib.dibujaTexto("Pluton",115,45);
        dib.ponColorLapiz(ColorFig.azul);
        dib.dibujaLinea(0,100, 30,100);
        dib.dibujaImagen(48,90,"caronte.png");
        dib.dibujaTexto("Caronte",75,105);
        dib.pinta();        
    }
}
