
/**
 * Programa que simula el funcionamiento del sistema
 * Pluton Caronte
 * 
 * @author (Michael) 
 * @version (8 marzo 2012)
 */
public class SimulaPluton
{
    // Espera un rato 
    private static void esperaUnRato() {
        try {
            // espera 200 milisegundos
            Thread.sleep(200); 
        } catch (InterruptedException e) {
            // ignorar
        }
    }

    /**
     * Programa principal que hace la simulacion
     */
    public static void main(String[] args) {
        // Creamos los astros
        // posiciones iniciales: 
        //   Pluton (0,0) Km
        //   Caronte (0,19570) Km
        // velocidades iniciales:
        //   Pluton (-23.71,0) m/s
        //   Caronte (195.0,0) m/s
        // masas:
        //   Pluton: 1.25e22 Kg
        //   Caronte: 1.52e21 Kg
        Astro caronte = new Astro(0.0,19.570e6,195.0,0.0,1.52e21);
        Astro pluton=new Astro(0.0,0.0,-23.71,0.0,1.25e22); 

        // Creamos la ventana para dibujar
        Espacio espacio=new Espacio();

        // inciamos un bucle que se repite 2 mil millones de veces
        int contador=0;
        while (contador<2_000_000_000) {
            // cada 10000 veces pintamos los astros y esperamos un rato
            if (contador%10000==0) {
                espacio.pintaAstro(caronte.posX(),caronte.posY(),Espacio.CARONTE);
                espacio.pintaAstro(pluton.posX(),pluton.posY(),Espacio.PLUTON);
                esperaUnRato();
            }

            // avanzamos 1 segundo (simuladamente)
            caronte.avanzaTiempo(1.0,pluton); 
            pluton.avanzaTiempo(1.0,caronte); 

            // cada mil millones de veces borramos las trayectorias
            if (contador%1_000_000_000==0) {
                espacio.borra();
            }
            contador++;
        }

    }
}
